@@ -7,8 +7,7 @@
 #include "followupreminder.h"
 #include "followupreminderinterface.h"
 
-#include <AkonadiCore/ServerManager>
-#include <servermanager.h>
+#include <Akonadi/ServerManager>
 
 using namespace MessageComposer;
 
