@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,6 +25,6 @@ protected Q_SLOTS:
     void doStart() override;
 
 private:
-    void addAttachment(const QByteArray &data, const QString &attachmentName);
+    MESSAGECOMPOSER_NO_EXPORT void addAttachment(const QByteArray &data, const QString &attachmentName);
 };
 }
