@@ -4,8 +4,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_ATTACHMENTJOB_H
-#define MESSAGECOMPOSER_ATTACHMENTJOB_H
+#pragma once
 
 #include "contentjobbase.h"
 #include "messagecomposer_export.h"
@@ -27,7 +26,7 @@ public:
     explicit AttachmentJob(MessageCore::AttachmentPart::Ptr part, QObject *parent = nullptr);
     ~AttachmentJob() override;
 
-    Q_REQUIRED_RESULT MessageCore::AttachmentPart::Ptr attachmentPart() const;
+    [[nodiscard]] MessageCore::AttachmentPart::Ptr attachmentPart() const;
     void setAttachmentPart(const MessageCore::AttachmentPart::Ptr &part);
 
 protected Q_SLOTS:
@@ -38,5 +37,3 @@ private:
     Q_DECLARE_PRIVATE(AttachmentJob)
 };
 }
-
-#endif
