@@ -963,19 +963,6 @@ void ThemeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
                                              mTheme->iconSize());
                 }
                 break;
-            case Theme::ContentItem::AnnotationIcon:
-                if (messageItem) {
-                    paint_boolean_state_icon(messageItem->hasAnnotation(),
-                                             mTheme->pixmap(Theme::IconAnnotation),
-                                             ci,
-                                             painter,
-                                             l,
-                                             top,
-                                             r,
-                                             layoutDir == Qt::LeftToRight,
-                                             mTheme->iconSize());
-                }
-                break;
             case Theme::ContentItem::InvitationIcon:
                 if (messageItem) {
                     paint_boolean_state_icon(messageItem->status().hasInvitation(),
@@ -1183,19 +1170,6 @@ void ThemeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
                                              mTheme->iconSize());
                 }
                 break;
-            case Theme::ContentItem::AnnotationIcon:
-                if (messageItem) {
-                    paint_boolean_state_icon(messageItem->hasAnnotation(),
-                                             mTheme->pixmap(Theme::IconAnnotation),
-                                             ci,
-                                             painter,
-                                             l,
-                                             top,
-                                             r,
-                                             layoutDir != Qt::LeftToRight,
-                                             mTheme->iconSize());
-                }
-                break;
             case Theme::ContentItem::InvitationIcon:
                 if (messageItem) {
                     paint_boolean_state_icon(messageItem->status().hasInvitation(),
@@ -1481,18 +1455,6 @@ bool ThemeDelegate::hitTest(const QPoint &viewportPoint, bool exact)
                                                                  mTheme->iconSize());
                 }
                 break;
-            case Theme::ContentItem::AnnotationIcon:
-                if (messageItem) {
-                    compute_bounding_rect_for_boolean_state_icon(messageItem->hasAnnotation(),
-                                                                 ci,
-                                                                 l,
-                                                                 top,
-                                                                 r,
-                                                                 mHitContentItemRect,
-                                                                 layoutDir == Qt::LeftToRight,
-                                                                 mTheme->iconSize());
-                }
-                break;
             case Theme::ContentItem::InvitationIcon:
                 if (messageItem) {
                     compute_bounding_rect_for_boolean_state_icon(messageItem->status().hasInvitation(),
@@ -1690,18 +1652,6 @@ bool ThemeDelegate::hitTest(const QPoint &viewportPoint, bool exact)
                                                                  mTheme->iconSize());
                 }
                 break;
-            case Theme::ContentItem::AnnotationIcon:
-                if (messageItem) {
-                    compute_bounding_rect_for_boolean_state_icon(messageItem->hasAnnotation(),
-                                                                 ci,
-                                                                 l,
-                                                                 top,
-                                                                 r,
-                                                                 mHitContentItemRect,
-                                                                 layoutDir != Qt::LeftToRight,
-                                                                 mTheme->iconSize());
-                }
-                break;
             case Theme::ContentItem::InvitationIcon:
                 if (messageItem) {
                     compute_bounding_rect_for_boolean_state_icon(messageItem->status().hasInvitation(),
