@@ -6,12 +6,12 @@
 
 #pragma once
 
+#include <Akonadi/Item>
 #include <MessageList/QuickSearchLine>
+#include <MessageList/SearchLineCommand>
 #include <MessageList/View>
 #include <MessageList/WidgetBase>
 
-#include <Akonadi/Item>
-
 #include <KMime/Message>
 
 #include "messagelist_export.h"
@@ -311,6 +311,8 @@ public:
     void setQuickSearchClickMessage(const QString &msg);
     [[nodiscard]] MessageList::Core::SearchMessageByButtons::SearchOptions currentOptions() const;
 
+    [[nodiscard]] QList<MessageList::Core::SearchLineCommand::SearchLineInfo> searchLineCommands() const;
+
 protected:
     /**
      * Reimplemented from MessageList::Core::Widget
