@@ -77,8 +77,8 @@ void ScamDetectionDetailsDialog::slotSaveAs()
             }
             QTextStream ts(&file);
             QString htmlStr = mDetails->toHtml();
-            htmlStr.replace(QLatin1String(R"(meta name="qrichtext" content="1")"),
-                            QLatin1String(R"(meta http-equiv="Content-Type" content="text/html; charset=UTF-8")"));
+            htmlStr.replace(QLatin1StringView(R"(meta name="qrichtext" content="1")"),
+                            QLatin1StringView(R"(meta http-equiv="Content-Type" content="text/html; charset=UTF-8")"));
             ts << htmlStr;
             file.close();
         }
@@ -94,14 +94,14 @@ void ScamDetectionDetailsDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(600, 200));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myScamDetectionDetailsDialogConfigGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myScamDetectionDetailsDialogConfigGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void ScamDetectionDetailsDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myScamDetectionDetailsDialogConfigGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myScamDetectionDetailsDialogConfigGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
 }
 
